@@ -1,4 +1,10 @@
 from datetime import datetime
+from . import six
+try:
+	import numpy as np
+	HAS_NUMPY = True
+except:
+	HAS_NUMPY = False
 
 class DataTypes(object):
 	BOOLEAN = 0
@@ -11,6 +17,8 @@ class DataTypes(object):
 	FORMULA = 7
 	
 	_enumerations = ["b", "d", "e", "inlineStr", "n", "s", "str"]
+	_numberTypes = six.integer_types + (float, complex)
+
 	@staticmethod
 	def to_enumeration_value(index):
 		return DataTypes._enumerations[index]
@@ -18,21 +26,23 @@ class DataTypes(object):
 	@staticmethod
 	def get_type(value):
 		# Using value.__class__ over isinstance for speed
-		if value.__class__ == str:
+		if value.__class__ in six.string_types:
 			if len(value) > 0 and value[0] == '=':
 				return DataTypes.FORMULA
 			else:
 				return DataTypes.INLINE_STRING
 		# not using in (int, float, long, complex) for speed
-		elif value.__class__ == int or value.__class__ == float or value.__class__ == long or value.__class__ == complex:
+		elif value.__class__ in DataTypes._numberTypes:
 			return DataTypes.NUMBER
 		# fall back to the slower isinstance
-		elif isinstance(value, basestring):
+		elif isinstance(value, six.string_types):
 			if len(value) > 0 and value[0] == '=':
 				return DataTypes.FORMULA
 			else:
 				return DataTypes.INLINE_STRING
-		elif isinstance(value, (int, float, long, complex)):
+		elif isinstance(value, DataTypes._numberTypes):
+			return DataTypes.NUMBER
+		elif HAS_NUMPY and isinstance(value, (np.floating, np.integer, np.complexfloating, np.unsignedinteger)):
 			return DataTypes.NUMBER
 		elif isinstance(value, datetime):
 			return DataTypes.DATE
