@@ -1,4 +1,5 @@
 from . import DataTypes
+from . import six
 
 class Range(object):
 	A = ord('A')
@@ -167,14 +168,13 @@ class Range(object):
 			s = ""	
 			while y >= 0:
 				s = chr((y % 26) + Range.A) + s
-				y /= 26
-				y -= 1
+				y = int(y / 26) - 1
 			Range._cts_cache[y] = s
 		return Range._cts_cache[y] + str(coord[0])
 	
 	@staticmethod
 	def to_coordinate(value):
-		if isinstance(value, basestring):
+		if isinstance(value, six.string_types):
 			value = Range.string_to_coordinate(value)
 		if (value[0] < 1 or value[0] > 65536) and value[1] != float('inf'):
 			raise Exception("Row index out of bounds")
